@@ -268,6 +268,13 @@ def predict_batch(params, gpu_id="0", roi_bins=list(range(0, 112)), atlas="DKT",
     os.environ["TF_CPP_MIN_LOG_LEVEL"] = "3"
     print(f"[predict_batch] GPU_ID: {gpu_id}")
     import tensorflow as tf
+    try:
+        tf.compat.v1.logging.set_verbosity(tf.compat.v1.logging.ERROR)
+        tf.compat.v1.disable_eager_execution()
+        from tensorflow.python.compiler.mlcompute import mlcompute
+        mlcompute.set_mlc_device(device_name="gpu") # Available options are 'cpu', 'gpu', and ‘any'.
+    except:
+        pass
     gpus = tf.config.experimental.list_physical_devices("GPU")
     for gpu in gpus:
         tf.config.experimental.set_memory_growth(gpu, True)
@@ -397,7 +404,6 @@ def main():
         print(f"[main] # samples: {len(params)}, mode: {mode}")
         predict_in_batch_mode_cpu(params, args.n_cores, roi_bins=args.rois, is_purge=args.purge_output)
 
-
 if __name__ == '__main__':
     main()
     
\ No newline at end of file
