@@ -55,8 +55,13 @@ def _get_available_GPUs(queue, including_gpus=None, excluding_gpus=None, memory_
 
 def get_available_GPUs(including_gpus=None, excluding_gpus=None, memory_per_process=7000000000):
     try:
+        import tensorflow as tf 
+        tf.compat.v1.disable_eager_execution()
         from tensorflow.python.compiler.mlcompute import mlcompute
         mlcompute.set_mlc_device(device_name="gpu") # Available options are 'cpu', 'gpu', and ‘any'.
+        gpus = ",".join([str(s) for s in range(8)])
+        n_chunks = 1
+        return gpus, n_chunks
     except:
         pass
     import multiprocessing
